Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(956)

Unified Diff: src/heap.h

Issue 10878047: Revert to code state of 3.13.1 plus r12350 (Closed) Base URL: https://v8.googlecode.com/svn/trunk
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/handles.cc ('k') | src/heap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap.h
diff --git a/src/heap.h b/src/heap.h
index ae9791469415d756d48e334684814eeb061957c9..f01af258bcd13cef73ac88e6cf1b14dda8f71d82 100644
--- a/src/heap.h
+++ b/src/heap.h
@@ -64,7 +64,7 @@ namespace internal {
V(Map, ascii_symbol_map, AsciiSymbolMap) \
V(Map, ascii_string_map, AsciiStringMap) \
V(Map, heap_number_map, HeapNumberMap) \
- V(Map, native_context_map, NativeContextMap) \
+ V(Map, global_context_map, GlobalContextMap) \
V(Map, fixed_array_map, FixedArrayMap) \
V(Map, code_map, CodeMap) \
V(Map, scope_info_map, ScopeInfoMap) \
@@ -150,8 +150,7 @@ namespace internal {
V(Smi, real_stack_limit, RealStackLimit) \
V(StringDictionary, intrinsic_function_names, IntrinsicFunctionNames) \
V(Smi, arguments_adaptor_deopt_pc_offset, ArgumentsAdaptorDeoptPCOffset) \
- V(Smi, construct_stub_deopt_pc_offset, ConstructStubDeoptPCOffset) \
- V(Smi, setter_stub_deopt_pc_offset, SetterStubDeoptPCOffset)
+ V(Smi, construct_stub_deopt_pc_offset, ConstructStubDeoptPCOffset)
#define ROOT_LIST(V) \
STRONG_ROOT_LIST(V) \
@@ -823,8 +822,8 @@ class Heap {
MUST_USE_RESULT MaybeObject* AllocateHashTable(
int length, PretenureFlag pretenure = NOT_TENURED);
- // Allocate a native (but otherwise uninitialized) context.
- MUST_USE_RESULT MaybeObject* AllocateNativeContext();
+ // Allocate a global (but otherwise uninitialized) context.
+ MUST_USE_RESULT MaybeObject* AllocateGlobalContext();
// Allocate a module context.
MUST_USE_RESULT MaybeObject* AllocateModuleContext(ScopeInfo* scope_info);
@@ -1074,10 +1073,7 @@ class Heap {
void EnsureHeapIsIterable();
// Notify the heap that a context has been disposed.
- int NotifyContextDisposed() {
- flush_monomorphic_ics_ = true;
- return ++contexts_disposed_;
- }
+ int NotifyContextDisposed() { return ++contexts_disposed_; }
// Utility to invoke the scavenger. This is needed in test code to
// ensure correct callback for weak global handles.
@@ -1105,8 +1101,8 @@ class Heap {
#endif
void AddGCPrologueCallback(
- GCPrologueCallback callback, GCType gc_type_filter);
- void RemoveGCPrologueCallback(GCPrologueCallback callback);
+ GCEpilogueCallback callback, GCType gc_type_filter);
+ void RemoveGCPrologueCallback(GCEpilogueCallback callback);
void AddGCEpilogueCallback(
GCEpilogueCallback callback, GCType gc_type_filter);
@@ -1153,10 +1149,10 @@ class Heap {
// not match the empty string.
String* hidden_symbol() { return hidden_symbol_; }
- void set_native_contexts_list(Object* object) {
- native_contexts_list_ = object;
+ void set_global_contexts_list(Object* object) {
+ global_contexts_list_ = object;
}
- Object* native_contexts_list() { return native_contexts_list_; }
+ Object* global_contexts_list() { return global_contexts_list_; }
// Number of mark-sweeps.
unsigned int ms_count() { return ms_count_; }
@@ -1230,9 +1226,9 @@ class Heap {
return reinterpret_cast<Address*>(&roots_[kStoreBufferTopRootIndex]);
}
- // Get address of native contexts list for serialization support.
- Object** native_contexts_list_address() {
- return &native_contexts_list_;
+ // Get address of global contexts list for serialization support.
+ Object** global_contexts_list_address() {
+ return &global_contexts_list_;
}
#ifdef DEBUG
@@ -1589,11 +1585,6 @@ class Heap {
set_construct_stub_deopt_pc_offset(Smi::FromInt(pc_offset));
}
- void SetSetterStubDeoptPCOffset(int pc_offset) {
- ASSERT(setter_stub_deopt_pc_offset() == Smi::FromInt(0));
- set_setter_stub_deopt_pc_offset(Smi::FromInt(pc_offset));
- }
-
// For post mortem debugging.
void RememberUnmappedPage(Address page, bool compacted);
@@ -1607,8 +1598,6 @@ class Heap {
global_ic_age_ = (global_ic_age_ + 1) & SharedFunctionInfo::ICAgeBits::kMax;
}
- bool flush_monomorphic_ics() { return flush_monomorphic_ics_; }
-
intptr_t amount_of_external_allocated_memory() {
return amount_of_external_allocated_memory_;
}
@@ -1694,8 +1683,6 @@ class Heap {
int global_ic_age_;
- bool flush_monomorphic_ics_;
-
int scan_on_scavenge_pages_;
#if defined(V8_TARGET_ARCH_X64)
@@ -1789,7 +1776,7 @@ class Heap {
// last GC.
int old_gen_exhausted_;
- Object* native_contexts_list_;
+ Object* global_contexts_list_;
StoreBufferRebuilder store_buffer_rebuilder_;
« no previous file with comments | « src/handles.cc ('k') | src/heap.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698